﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class TakeCheese : MonoBehaviour 
{
    //チーズタグの名前
    [SerializeField]
    string cheeseTagName = "Cheese";

    //チーズが取れる範囲
    [SerializeField]
    float rangeTake = 1.0f;

    //チーズをどのくらい前に置くか
    [SerializeField]
    float distancePut = 0.9f;

    //チーズが取れる正面ベクトルからの角度(degree)
    [SerializeField]
    float takeDeg = 45.0f;

    //チーズを取るときに押すボタン
    [SerializeField]
    KeyCode takeCheeseKey = KeyCode.Space;

    //チーズを持っているか
    private bool isTakeCheese = false;

    //持っているチーズ
    private Cheese takenCheese = null;

    //自分自身のトランスフォーム
    private Transform ownTrans;

	// Use this for initialization
	void Start () 
    {
        ownTrans = GetComponent<Transform>();
	}
	
	// Update is called once per frame
	void Update () 
    {
		if(Input.GetKeyDown(takeCheeseKey))
        {
            if(!isTakeCheese)
            {
                PickCheese();
            }
            else
            {
                PutCheese();
            }
        }
	}

    /// <summary>
    /// チーズを取る関数
    /// </summary>
    void PickCheese()
    {
        GameObject[] cheeses = GameObject.FindGameObjectsWithTag(cheeseTagName);

        foreach(GameObject cheese in cheeses)
        {
            Vector3 dir = cheese.GetComponent<Transform>().position - ownTrans.position;
            float distance = dir.magnitude;

            if (!(rangeTake > 0 && distance <= rangeTake))
                continue;

            float deg = Vector3.Angle(ownTrans.forward, dir.normalized);

            if(deg <= takeDeg)
            {
                Cheese cheeseSrc = cheese.GetComponent<Cheese>();

                if(cheeseSrc)
                {
                    cheeseSrc.Take(ownTrans);

                    isTakeCheese = true;

                    takenCheese = cheeseSrc;

                    break;
                }
            }
            else
            {
                Debug.LogWarning(cheese.name + "doesn't set Cheese script");
            }
        }
    }

    /// <summary>
    /// チーズを置く関数
    /// </summary>
    void PutCheese()
    {
        Vector3 putPos = ownTrans.position + ownTrans.forward * distancePut;
        putPos.y = takenCheese.StartPosY;

        takenCheese.Put(putPos);

        takenCheese = null;
        isTakeCheese = false;
    }
}
